package com.diagbot.web;


import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.UserAuthenticationDTO;
import com.diagbot.dto.UserAuthenticationRespDTO;
import com.diagbot.entity.UserAuthentication;
import com.diagbot.facade.UserAuthenticationFacade;
import com.diagbot.vo.UserAuthenticationVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 用户认证信息表 前端控制器
 * </p>
 *
 * @author zhaops
 * @since 2018-09-13
 */
@RestController
@RequestMapping("/userAuthentication")
public class UserAuthenticationController {
    @Autowired
    private UserAuthenticationFacade userAuthenticationFacade;


    @ApiOperation(value = "用户认证",
            notes = "userName：用户名，必填<br>" +
                    "organization：组织机构，必填<br>")
    @PostMapping("/userAuthentication")
    @SysLogger("userAuthentication")
    public RespDTO<UserAuthenticationRespDTO> userAuthentication(@RequestBody @Valid UserAuthenticationVO userAuthenticationVO) {
        UserAuthenticationRespDTO userAuthenticationRespDTO = userAuthenticationFacade.userAuthentication(userAuthenticationVO);
        return RespDTO.onSuc(userAuthenticationRespDTO);
    }

    @ApiOperation(value = "获取当前用户信息")
    @PostMapping("/getuserAuthenticationInfo")
    @SysLogger("getuserAuthenticationInfo")
    public RespDTO<UserAuthenticationDTO> getuserAuthenticationInfo() {
        UserAuthenticationDTO userAuthenticationDTO = userAuthenticationFacade.getuserAuthenticationInfo();
        return RespDTO.onSuc(userAuthenticationDTO);
    }

    @ApiOperation(value = "获取当前用户认证信息")
    @PostMapping("/getUserAuthentication")
    @SysLogger("getUserAuthentication")
    public RespDTO<UserAuthentication> getUserAuthentication() {
        UserAuthentication userAuthentication = userAuthenticationFacade.getUserAuthentication();
        return RespDTO.onSuc(userAuthentication);
    }
}
